Bootstrap-session-timeout - Countdown Timer

# Bootstrap-session-timeout

## Countdown Timer

Shows the warning dialog with countdown timer after 3 seconds. If user takes no action (interacts with the page in any way), browser is redirected to redirUrl. On any user action (mouse, keyboard or touch) the timeout timer as well as the countdown timer are reset (visible if you don't close the warning dialog).

                $.sessionTimeout({
                    keepAliveUrl: 'keep-alive.html',
                    logoutUrl: 'login.html',
                    redirUrl: 'locked.html',
                    warnAfter: 3000,
                    redirAfter: 10000,
                    countdownMessage: 'Redirecting in {timer} seconds.'
                });

Back to Demo Index